# Release History

## 1.1.1 (08/05/2022)

- Standardized documentation

- Updated azure-storage-blob dependency to v12.13.1

## 1.1.0 (08/05/2022)

- Asynchronous and synchronous clients available

- Complete API documentation

- Test suite for versioning, async client and sync client

## 1.0.1 (08/04/2022)

- Naming conventions bug fix

## 1.0.0 (08/02/2022)

- Initial Release

- Configured, CHANGELOG, LICENSE, and MANIFEST

- Connect to cloud-based or IoT Edge-based storage accounts

- Connect via connection string or storage account key
